
History
=======

1.2
---

- Add ``clear soup`` functionality to the controlpanel.
  [fRiSi]


1.1
---

- Plone conform status message markup
  [petschki]

- Fix id in status message
  [petschki]

- Fix tests
  [rnix]

- Make ``get_soup`` consistent
  [jean]

- Revise documentation
  [jean]


1.0
---

- Added missing MANIFEST.in
  [jensens]


1.0-beta
--------

- Make it work
  [rnix, jensens, et al]
